Module: Google::Apis::AppsmarketV2
- Defined in:
- lib/google/apis/appsmarket_v2.rb,
lib/google/apis/appsmarket_v2/classes.rb,
lib/google/apis/appsmarket_v2/service.rb,
lib/google/apis/appsmarket_v2/gem_version.rb,
lib/google/apis/appsmarket_v2/representations.rb
Overview
Google Workspace Marketplace API
Lets your Google Workspace Marketplace applications integrate with Google's installtion and licensing services.
Defined Under Namespace
Classes: CustomerLicense, Editions, GSuiteMarketplaceAPIService, UserLicense
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-appsmarket_v2 gem
"0.4.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260209"- VERSION =
Version of the Google Workspace Marketplace API this client connects to. This is NOT the gem version.
'V2'- AUTH_APPSMARKETPLACE_LICENSE =
View your installed application's licensing information
'https://www.googleapis.com/auth/appsmarketplace.license'