Class: Google::Apis::AppsmarketV2::GSuiteMarketplaceAPIService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AppsmarketV2::GSuiteMarketplaceAPIService
- Defined in:
- lib/google/apis/appsmarket_v2/service.rb
Overview
Google Workspace Marketplace API
Lets your Google Workspace Marketplace applications integrate with Google's installtion and licensing services.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://appsmarket.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#get_customer_license(application_id, customer_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppsmarketV2::CustomerLicense
Gets the customer's licensing status to determine if they have access to a given app.
-
#get_user_license(application_id, user_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppsmarketV2::UserLicense
Gets the user's licensing status to determine if they have permission to use a given app.
-
#initialize ⇒ GSuiteMarketplaceAPIService
constructor
A new instance of GSuiteMarketplaceAPIService.
Constructor Details
#initialize ⇒ GSuiteMarketplaceAPIService
Returns a new instance of GSuiteMarketplaceAPIService.
48 49 50 51 52 53 |
# File 'lib/google/apis/appsmarket_v2/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-appsmarket_v2', client_version: Google::Apis::AppsmarketV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/appsmarket_v2/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/appsmarket_v2/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#get_customer_license(application_id, customer_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppsmarketV2::CustomerLicense
Gets the customer's licensing status to determine if they have access to a given app. For more information, see Getting app installation and licensing details.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/apis/appsmarket_v2/service.rb', line 80 def get_customer_license(application_id, customer_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'appsmarket/v2/customerLicense/{applicationId}/{customerId}', ) command.response_representation = Google::Apis::AppsmarketV2::CustomerLicense::Representation command.response_class = Google::Apis::AppsmarketV2::CustomerLicense command.params['applicationId'] = application_id unless application_id.nil? command.params['customerId'] = customer_id unless customer_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_user_license(application_id, user_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppsmarketV2::UserLicense
Gets the user's licensing status to determine if they have permission to use a given app. For more information, see Getting app installation and licensing details.
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/google/apis/appsmarket_v2/service.rb', line 116 def get_user_license(application_id, user_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'appsmarket/v2/userLicense/{applicationId}/{userId}', ) command.response_representation = Google::Apis::AppsmarketV2::UserLicense::Representation command.response_class = Google::Apis::AppsmarketV2::UserLicense command.params['applicationId'] = application_id unless application_id.nil? command.params['userId'] = user_id unless user_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |