Class: Google::Apis::AppsmarketV2::UserLicense
- Inherits:
-
Object
- Object
- Google::Apis::AppsmarketV2::UserLicense
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appsmarket_v2/classes.rb,
lib/google/apis/appsmarket_v2/representations.rb,
lib/google/apis/appsmarket_v2/representations.rb
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application corresponding to the license query.
-
#customer_id ⇒ String
The domain name of the user.
-
#edition_id ⇒ String
(Deprecated) Corresponds to the JSON property
editionId. -
#enabled ⇒ Boolean
(also: #enabled?)
The domain administrator has activated the application for this domain.
-
#id ⇒ String
The ID of the user license.
-
#kind ⇒ String
The type of API resource.
-
#state ⇒ String
The user's licensing status.
-
#user_id ⇒ String
The email address of the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserLicense
constructor
A new instance of UserLicense.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserLicense
Returns a new instance of UserLicense.
156 157 158 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_id ⇒ String
The ID of the application corresponding to the license query.
Corresponds to the JSON property applicationId
114 115 116 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 114 def application_id @application_id end |
#customer_id ⇒ String
The domain name of the user.
Corresponds to the JSON property customerId
119 120 121 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 119 def customer_id @customer_id end |
#edition_id ⇒ String
(Deprecated)
Corresponds to the JSON property editionId
124 125 126 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 124 def edition_id @edition_id end |
#enabled ⇒ Boolean Also known as: enabled?
The domain administrator has activated the application for this domain.
Corresponds to the JSON property enabled
129 130 131 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 129 def enabled @enabled end |
#id ⇒ String
The ID of the user license.
Corresponds to the JSON property id
135 136 137 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 135 def id @id end |
#kind ⇒ String
The type of API resource. This is always appsmarket#userLicense.
Corresponds to the JSON property kind
140 141 142 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 140 def kind @kind end |
#state ⇒ String
The user's licensing status. One of: - ACTIVE: The user has a valid license
and should be permitted to use the application. - UNLICENSED: The
administrator of this user's domain never assigned a seat for the application
to this user. - EXPIRED: The administrator assigned a seat to this user, but
the license is expired.
Corresponds to the JSON property state
149 150 151 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 149 def state @state end |
#user_id ⇒ String
The email address of the user.
Corresponds to the JSON property userId
154 155 156 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 154 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/google/apis/appsmarket_v2/classes.rb', line 161 def update!(**args) @application_id = args[:application_id] if args.key?(:application_id) @customer_id = args[:customer_id] if args.key?(:customer_id) @edition_id = args[:edition_id] if args.key?(:edition_id) @enabled = args[:enabled] if args.key?(:enabled) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @state = args[:state] if args.key?(:state) @user_id = args[:user_id] if args.key?(:user_id) end |